@@ -19,7 +19,7 @@ class BadOutputError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -41,7 +41,7 @@ class BadCrtcError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -63,7 +63,7 @@ class BadModeError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -85,7 +85,7 @@ class BadProviderError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -116,7 +116,7 @@ class ScreenSize(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.width, self.height, self.mwidth, self.mheight = unpacker.unpack("HHHH")
+        self.width, self.height, self.mwidth, self.mheight = unpacker.unpack("=HHHH")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -146,7 +146,7 @@ class RefreshRates(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        (self.nRates,) = unpacker.unpack("H")
+        (self.nRates,) = unpacker.unpack("=H")
         self.rates = xcffib.List(unpacker, "H", self.nRates)
         self.bufsize = unpacker.offset - base
 
@@ -172,7 +172,7 @@ class QueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xx2x4xII16x")
+        self.major_version, self.minor_version = unpacker.unpack("=xx2x4xII16x")
         self.bufsize = unpacker.offset - base
 
 
@@ -201,7 +201,7 @@ class SetScreenConfigReply(xcffib.Reply):
             self.config_timestamp,
             self.root,
             self.subpixel_order,
-        ) = unpacker.unpack("xB2x4xIIIH10x")
+        ) = unpacker.unpack("=xB2x4xIIIH10x")
         self.bufsize = unpacker.offset - base
 
 
@@ -238,7 +238,7 @@ class GetScreenInfoReply(xcffib.Reply):
             self.rotation,
             self.rate,
             self.nInfo,
-        ) = unpacker.unpack("xB2x4xIIIHHHHH2x")
+        ) = unpacker.unpack("=xB2x4xIIIHHHHH2x")
         self.sizes = xcffib.List(unpacker, ScreenSize, self.nSizes)
         unpacker.pad(RefreshRates)
         self.rates = xcffib.List(unpacker, RefreshRates, self.nInfo - self.nSizes)
@@ -258,7 +258,7 @@ class GetScreenSizeRangeReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.min_width, self.min_height, self.max_width, self.max_height = (
-            unpacker.unpack("xx2x4xHHHH16x")
+            unpacker.unpack("=xx2x4xHHHH16x")
         )
         self.bufsize = unpacker.offset - base
 
@@ -306,7 +306,7 @@ class ModeInfo(xcffib.Struct):
             self.vtotal,
             self.name_len,
             self.mode_flags,
-        ) = unpacker.unpack("IHHIHHHHHHHHI")
+        ) = unpacker.unpack("=IHHIHHHHHHHHI")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -382,7 +382,7 @@ class GetScreenResourcesReply(xcffib.Reply):
             self.num_outputs,
             self.num_modes,
             self.names_len,
-        ) = unpacker.unpack("xx2x4xIIHHHH8x")
+        ) = unpacker.unpack("=xx2x4xIIHHHH8x")
         self.crtcs = xcffib.List(unpacker, "I", self.num_crtcs)
         unpacker.pad("I")
         self.outputs = xcffib.List(unpacker, "I", self.num_outputs)
@@ -424,7 +424,7 @@ class GetOutputInfoReply(xcffib.Reply):
             self.num_preferred,
             self.num_clones,
             self.name_len,
-        ) = unpacker.unpack("xB2x4xIIIIBBHHHHH")
+        ) = unpacker.unpack("=xB2x4xIIIIBBHHHHH")
         self.crtcs = xcffib.List(unpacker, "I", self.num_crtcs)
         unpacker.pad("I")
         self.modes = xcffib.List(unpacker, "I", self.num_modes)
@@ -447,7 +447,7 @@ class ListOutputPropertiesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.num_atoms,) = unpacker.unpack("xx2x4xH22x")
+        (self.num_atoms,) = unpacker.unpack("=xx2x4xH22x")
         self.atoms = xcffib.List(unpacker, "I", self.num_atoms)
         self.bufsize = unpacker.offset - base
 
@@ -464,7 +464,7 @@ class QueryOutputPropertyReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.pending, self.range, self.immutable = unpacker.unpack("xx2x4xBBB21x")
+        self.pending, self.range, self.immutable = unpacker.unpack("=xx2x4xBBB21x")
         self.validValues = xcffib.List(unpacker, "i", self.length)
         self.bufsize = unpacker.offset - base
 
@@ -482,7 +482,7 @@ class GetOutputPropertyReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.format, self.type, self.bytes_after, self.num_items = unpacker.unpack(
-            "xB2x4xIII12x"
+            "=xB2x4xIII12x"
         )
         self.data = xcffib.List(unpacker, "B", self.num_items * (self.format // 8))
         self.bufsize = unpacker.offset - base
@@ -500,7 +500,7 @@ class CreateModeReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.mode,) = unpacker.unpack("xx2x4xI20x")
+        (self.mode,) = unpacker.unpack("=xx2x4xI20x")
         self.bufsize = unpacker.offset - base
 
 
@@ -528,7 +528,7 @@ class GetCrtcInfoReply(xcffib.Reply):
             self.rotations,
             self.num_outputs,
             self.num_possible_outputs,
-        ) = unpacker.unpack("xB2x4xIhhHHIHHHH")
+        ) = unpacker.unpack("=xB2x4xIhhHHIHHHH")
         self.outputs = xcffib.List(unpacker, "I", self.num_outputs)
         unpacker.pad("I")
         self.possible = xcffib.List(unpacker, "I", self.num_possible_outputs)
@@ -547,7 +547,7 @@ class SetCrtcConfigReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.status, self.timestamp = unpacker.unpack("xB2x4xI20x")
+        self.status, self.timestamp = unpacker.unpack("=xB2x4xI20x")
         self.bufsize = unpacker.offset - base
 
 
@@ -563,7 +563,7 @@ class GetCrtcGammaSizeReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.size,) = unpacker.unpack("xx2x4xH22x")
+        (self.size,) = unpacker.unpack("=xx2x4xH22x")
         self.bufsize = unpacker.offset - base
 
 
@@ -579,7 +579,7 @@ class GetCrtcGammaReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.size,) = unpacker.unpack("xx2x4xH22x")
+        (self.size,) = unpacker.unpack("=xx2x4xH22x")
         self.red = xcffib.List(unpacker, "H", self.size)
         unpacker.pad("H")
         self.green = xcffib.List(unpacker, "H", self.size)
@@ -607,7 +607,7 @@ class GetScreenResourcesCurrentReply(xcffib.Reply):
             self.num_outputs,
             self.num_modes,
             self.names_len,
-        ) = unpacker.unpack("xx2x4xIIHHHH8x")
+        ) = unpacker.unpack("=xx2x4xIIHHHH8x")
         self.crtcs = xcffib.List(unpacker, "I", self.num_crtcs)
         unpacker.pad("I")
         self.outputs = xcffib.List(unpacker, "I", self.num_outputs)
@@ -637,9 +637,9 @@ class GetCrtcTransformReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x4x")
+        unpacker.unpack("=xx2x4x")
         self.pending_transform = render.TRANSFORM(unpacker)
-        (self.has_transforms,) = unpacker.unpack("B3x")
+        (self.has_transforms,) = unpacker.unpack("=B3x")
         unpacker.pad(render.TRANSFORM)
         self.current_transform = render.TRANSFORM(unpacker)
         (
@@ -647,7 +647,7 @@ class GetCrtcTransformReply(xcffib.Reply):
             self.pending_nparams,
             self.current_len,
             self.current_nparams,
-        ) = unpacker.unpack("4xHHHH")
+        ) = unpacker.unpack("=4xHHHH")
         unpacker.pad("c")
         self.pending_filter_name = xcffib.List(unpacker, "c", self.pending_len)
         unpacker.pad("i")
@@ -686,7 +686,7 @@ class GetPanningReply(xcffib.Reply):
             self.border_top,
             self.border_right,
             self.border_bottom,
-        ) = unpacker.unpack("xB2x4xIHHHHHHHHhhhh")
+        ) = unpacker.unpack("=xB2x4xIHHHHHHHHhhhh")
         self.bufsize = unpacker.offset - base
 
 
@@ -702,7 +702,7 @@ class SetPanningReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.status, self.timestamp = unpacker.unpack("xB2x4xI")
+        self.status, self.timestamp = unpacker.unpack("=xB2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -718,7 +718,7 @@ class GetOutputPrimaryReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.output,) = unpacker.unpack("xx2x4xI")
+        (self.output,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -734,7 +734,7 @@ class GetProvidersReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.timestamp, self.num_providers = unpacker.unpack("xx2x4xIH18x")
+        self.timestamp, self.num_providers = unpacker.unpack("=xx2x4xIH18x")
         self.providers = xcffib.List(unpacker, "I", self.num_providers)
         self.bufsize = unpacker.offset - base
 
@@ -766,7 +766,7 @@ class GetProviderInfoReply(xcffib.Reply):
             self.num_outputs,
             self.num_associated_providers,
             self.name_len,
-        ) = unpacker.unpack("xB2x4xIIHHHH8x")
+        ) = unpacker.unpack("=xB2x4xIIHHHH8x")
         self.crtcs = xcffib.List(unpacker, "I", self.num_crtcs)
         unpacker.pad("I")
         self.outputs = xcffib.List(unpacker, "I", self.num_outputs)
@@ -795,7 +795,7 @@ class ListProviderPropertiesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.num_atoms,) = unpacker.unpack("xx2x4xH22x")
+        (self.num_atoms,) = unpacker.unpack("=xx2x4xH22x")
         self.atoms = xcffib.List(unpacker, "I", self.num_atoms)
         self.bufsize = unpacker.offset - base
 
@@ -812,7 +812,7 @@ class QueryProviderPropertyReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.pending, self.range, self.immutable = unpacker.unpack("xx2x4xBBB21x")
+        self.pending, self.range, self.immutable = unpacker.unpack("=xx2x4xBBB21x")
         self.valid_values = xcffib.List(unpacker, "i", self.length)
         self.bufsize = unpacker.offset - base
 
@@ -830,7 +830,7 @@ class GetProviderPropertyReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.format, self.type, self.bytes_after, self.num_items = unpacker.unpack(
-            "xB2x4xIII12x"
+            "=xB2x4xIII12x"
         )
         self.data = xcffib.List(unpacker, "c", self.num_items * (self.format // 8))
         self.bufsize = unpacker.offset - base
@@ -860,7 +860,7 @@ class ScreenChangeNotifyEvent(xcffib.Event):
             self.height,
             self.mwidth,
             self.mheight,
-        ) = unpacker.unpack("xB2xIIIIHHHHHH")
+        ) = unpacker.unpack("=xB2xIIIIHHHHHH")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -948,7 +948,7 @@ class CrtcChange(xcffib.Struct):
             self.y,
             self.width,
             self.height,
-        ) = unpacker.unpack("IIIIH2xhhHH")
+        ) = unpacker.unpack("=IIIIH2xhhHH")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -1004,7 +1004,7 @@ class OutputChange(xcffib.Struct):
             self.rotation,
             self.connection,
             self.subpixel_order,
-        ) = unpacker.unpack("IIIIIIHBB")
+        ) = unpacker.unpack("=IIIIIIHBB")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -1062,7 +1062,7 @@ class OutputProperty(xcffib.Struct):
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
         self.window, self.output, self.atom, self.timestamp, self.status = (
-            unpacker.unpack("IIIIB11x")
+            unpacker.unpack("=IIIIB11x")
         )
         self.bufsize = unpacker.offset - base
 
@@ -1101,7 +1101,7 @@ class ProviderChange(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.timestamp, self.window, self.provider = unpacker.unpack("III16x")
+        self.timestamp, self.window, self.provider = unpacker.unpack("=III16x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -1129,7 +1129,7 @@ class ProviderProperty(xcffib.Struct):
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
         self.window, self.provider, self.atom, self.timestamp, self.state = (
-            unpacker.unpack("IIIIB11x")
+            unpacker.unpack("=IIIIB11x")
         )
         self.bufsize = unpacker.offset - base
 
@@ -1168,7 +1168,7 @@ class ResourceChange(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        self.timestamp, self.window = unpacker.unpack("II20x")
+        self.timestamp, self.window = unpacker.unpack("=II20x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -1205,7 +1205,7 @@ class MonitorInfo(xcffib.Struct):
             self.height,
             self.width_in_millimeters,
             self.height_in_millimeters,
-        ) = unpacker.unpack("IBBHhhHHII")
+        ) = unpacker.unpack("=IBBHhhHHII")
         self.outputs = xcffib.List(unpacker, "I", self.nOutput)
         self.bufsize = unpacker.offset - base
 
@@ -1267,7 +1267,7 @@ class GetMonitorsReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.timestamp, self.nMonitors, self.nOutputs = unpacker.unpack("xx2x4xIII12x")
+        self.timestamp, self.nMonitors, self.nOutputs = unpacker.unpack("=xx2x4xIII12x")
         self.monitors = xcffib.List(unpacker, MonitorInfo, self.nMonitors)
         self.bufsize = unpacker.offset - base
 
@@ -1284,7 +1284,7 @@ class CreateLeaseReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.nfd,) = unpacker.unpack("xB2x4x24x")
+        (self.nfd,) = unpacker.unpack("=xB2x4x24x")
         self.bufsize = unpacker.offset - base
 
 
@@ -1301,7 +1301,7 @@ class LeaseNotify(xcffib.Struct):
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
         self.timestamp, self.window, self.lease, self.created = unpacker.unpack(
-            "IIIB15x"
+            "=IIIB15x"
         )
         self.bufsize = unpacker.offset - base
 
@@ -1359,7 +1359,7 @@ class NotifyEvent(xcffib.Event):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
-        (self.subCode,) = unpacker.unpack("xB2x")
+        (self.subCode,) = unpacker.unpack("=xB2x")
         self.u = NotifyData(unpacker)
         self.bufsize = unpacker.offset - base
 
