@@ -18,9 +18,9 @@ class PRINTER(xcffib.Struct):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Struct.__init__(self, unpacker)
         base = unpacker.offset
-        (self.nameLen,) = unpacker.unpack("I")
+        (self.nameLen,) = unpacker.unpack("=I")
         self.name = xcffib.List(unpacker, "c", self.nameLen)
-        (self.descLen,) = unpacker.unpack("I")
+        (self.descLen,) = unpacker.unpack("=I")
         unpacker.pad("c")
         self.description = xcffib.List(unpacker, "c", self.descLen)
         self.bufsize = unpacker.offset - base
@@ -91,7 +91,7 @@ class PrintQueryVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xx2x4xHH")
+        self.major_version, self.minor_version = unpacker.unpack("=xx2x4xHH")
         self.bufsize = unpacker.offset - base
 
 
@@ -107,7 +107,7 @@ class PrintGetPrinterListReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.listCount,) = unpacker.unpack("xx2x4xI20x")
+        (self.listCount,) = unpacker.unpack("=xx2x4xI20x")
         self.printers = xcffib.List(unpacker, PRINTER, self.listCount)
         self.bufsize = unpacker.offset - base
 
@@ -124,7 +124,7 @@ class PrintGetContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.context,) = unpacker.unpack("xx2x4xI")
+        (self.context,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -140,7 +140,7 @@ class PrintGetScreenOfContextReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.root,) = unpacker.unpack("xx2x4xI")
+        (self.root,) = unpacker.unpack("=xx2x4xI")
         self.bufsize = unpacker.offset - base
 
 
@@ -157,7 +157,7 @@ class PrintGetDocumentDataReply(xcffib.Reply):
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.status_code, self.finished_flag, self.dataLen = unpacker.unpack(
-            "xx2x4xIII12x"
+            "=xx2x4xIII12x"
         )
         self.data = xcffib.List(unpacker, "B", self.dataLen)
         self.bufsize = unpacker.offset - base
@@ -175,7 +175,7 @@ class PrintInputSelectedReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.event_mask, self.all_events_mask = unpacker.unpack("xx2x4xII")
+        self.event_mask, self.all_events_mask = unpacker.unpack("=xx2x4xII")
         self.bufsize = unpacker.offset - base
 
 
@@ -191,7 +191,7 @@ class PrintGetAttributesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.stringLen,) = unpacker.unpack("xx2x4xI20x")
+        (self.stringLen,) = unpacker.unpack("=xx2x4xI20x")
         self.attributes = xcffib.List(unpacker, "c", self.stringLen)
         self.bufsize = unpacker.offset - base
 
@@ -208,7 +208,7 @@ class PrintGetOneAttributesReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.valueLen,) = unpacker.unpack("xx2x4xI20x")
+        (self.valueLen,) = unpacker.unpack("=xx2x4xI20x")
         self.value = xcffib.List(unpacker, "c", self.valueLen)
         self.bufsize = unpacker.offset - base
 
@@ -232,7 +232,7 @@ class PrintGetPageDimensionsReply(xcffib.Reply):
             self.offset_y,
             self.reproducible_width,
             self.reproducible_height,
-        ) = unpacker.unpack("xx2x4xHHHHHH")
+        ) = unpacker.unpack("=xx2x4xHHHHHH")
         self.bufsize = unpacker.offset - base
 
 
@@ -248,7 +248,7 @@ class PrintQueryScreensReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.listCount,) = unpacker.unpack("xx2x4xI20x")
+        (self.listCount,) = unpacker.unpack("=xx2x4xI20x")
         self.roots = xcffib.List(unpacker, "I", self.listCount)
         self.bufsize = unpacker.offset - base
 
@@ -265,7 +265,7 @@ class PrintSetImageResolutionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.status, self.previous_resolutions = unpacker.unpack("xB2x4xH")
+        self.status, self.previous_resolutions = unpacker.unpack("=xB2x4xH")
         self.bufsize = unpacker.offset - base
 
 
@@ -281,7 +281,7 @@ class PrintGetImageResolutionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.image_resolution,) = unpacker.unpack("xx2x4xH")
+        (self.image_resolution,) = unpacker.unpack("=xx2x4xH")
         self.bufsize = unpacker.offset - base
 
 
@@ -297,7 +297,7 @@ class NotifyEvent(xcffib.Event):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
-        self.detail, self.context, self.cancel = unpacker.unpack("xB2xIB")
+        self.detail, self.context, self.cancel = unpacker.unpack("=xB2xIB")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -329,7 +329,7 @@ class AttributNotifyEvent(xcffib.Event):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Event.__init__(self, unpacker)
         base = unpacker.offset
-        self.detail, self.context = unpacker.unpack("xB2xI")
+        self.detail, self.context = unpacker.unpack("=xB2xI")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -360,7 +360,7 @@ class BadContextError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
@@ -382,7 +382,7 @@ class BadSequenceError(xcffib.Error):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Error.__init__(self, unpacker)
         base = unpacker.offset
-        unpacker.unpack("xx2x")
+        unpacker.unpack("=xx2x")
         self.bufsize = unpacker.offset - base
 
     def pack(self):
