@@ -1,7 +1,6 @@
 import xcffib
 import struct
 import io
-from dataclasses import dataclass
 
 MAJOR_VERSION = 2
 MINOR_VERSION = 2
@@ -11,7 +10,6 @@ _errors = {}
 from . import xproto
 
 
-@dataclass(init=False)
 class GetVersionReply(xcffib.Reply):
     xge = False
 
@@ -20,22 +18,19 @@ class GetVersionReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        self.major_version, self.minor_version = unpacker.unpack("xB2x4xH")
+        self.major_version, self.minor_version = unpacker.unpack("=xB2x4xH")
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class GetVersionCookie(xcffib.Cookie):
     reply_type = GetVersionReply
 
 
-@dataclass(init=False)
 class Cursor:
     _None = 0
     Current = 1
 
 
-@dataclass(init=False)
 class CompareCursorReply(xcffib.Reply):
     xge = False
 
@@ -44,16 +39,14 @@ class CompareCursorReply(xcffib.Reply):
             unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
-        (self.same,) = unpacker.unpack("xB2x4x")
+        (self.same,) = unpacker.unpack("=xB2x4x")
         self.bufsize = unpacker.offset - base
 
 
-@dataclass(init=False)
 class CompareCursorCookie(xcffib.Cookie):
     reply_type = CompareCursorReply
 
 
-@dataclass(init=False)
 class xtestExtension(xcffib.Extension):
     def GetVersion(self, major_version, minor_version, is_checked=True):
         buf = io.BytesIO()
